@@ -12,8 +12,6 @@ from helpers import get_ojota_children, get_data_codes, get_form
 from renderers import render_field
 
 
-
-
 class Site(object):
     def __init__(self, package, title="Havaiana Powered Site",
                  renderers=None):
@@ -42,7 +40,7 @@ class Site(object):
         data = {}
 
         data['title'] = self.title
-        data['data_code'] = Ojota.CURRENT_DATA_CODE
+        data['data_code'] = Ojota.get_current_data_code()
         if data['data_code'] == "":
             data['data_code'] = "Root"
         data['data_codes'] = get_data_codes()
@@ -65,11 +63,11 @@ class Site(object):
         self.classes_map = {}
 
         for item in self.classes:
-           self.classes_map[item[1].plural_name] = item
+            self.classes_map[item[1].plural_name] = item
 
     def _map_urls(self):
         self.app.add_url_rule('/change-data-code/<data_code>',
-            'change_data_code', self.change_data_code)
+                              'change_data_code', self.change_data_code)
         self.app.add_url_rule("/new/<name>", "new", self.new,
                               methods=['GET', 'POST'])
         self.app.add_url_rule("/edit/<name>/<pk_>", "new", self.new,
@@ -81,7 +79,8 @@ class Site(object):
         self.app.add_url_rule('/media/<path:filename>', "custom_static",
                               self.custom_static)
         self.app.add_url_rule('/absolute//<path:filename>',
-            "custom_absolute_static", self.custom_absolute_static)
+                              "custom_absolute_static",
+                              self.custom_absolute_static)
         self.app.add_url_rule('/', "index", self.index)
 
         @self.app.errorhandler(404)
@@ -119,7 +118,7 @@ class Site(object):
                 data = request.form
             else:
                 update = True
-                data = cls.get(pk_)
+                data = cls.one(pk_)
 
             form = get_form(cls, data, update)
             # validate and save if there is data in to save.
@@ -141,7 +140,7 @@ class Site(object):
         if self.deletable:
             item = self.classes_map[name]
             cls = item[1]
-            element = cls.get(pk_)
+            element = cls.one(pk_)
             # show confirmation data.
 
             if request.method == 'GET':
@@ -166,7 +165,8 @@ class Site(object):
         try:
             item = self.classes_map[name]
         except KeyError:
-            data_dict['message'] = "The class <strong>%s</strong> does not exist"  % name
+            data_dict['message'] = \
+                "The class <strong>%s</strong> does not exist" % name
             return render_template("404.html", **data_dict), 404
 
         cls = item[1]
@@ -185,7 +185,7 @@ class Site(object):
             if order is None and cls.default_order is not None:
                 order = cls.default_order
 
-            items = cls.all(sorted=order)
+            items = cls.many(sorted=order)
 
             # getting the fields for all the items.
             fields = []
@@ -205,21 +205,26 @@ class Site(object):
                 grid_item = [(item, item.primary_key)]
                 for field in fields:
                     # here is where I render the widgets.
-                    class_renderers = self.renderers[item.__class__.__name__].items() \
-                        if item.__class__.__name__ in self.renderers else []
-                    grid_item.append(render_field(field, item, class_renderers))
+                    if item.__class__.__name__ in self.renderers:
+                        _class_name = item.__class__.__name__
+                        class_renderers = self.renderers[_class_name].items()
+                    else:
+                        class_renderers = []
+                    grid_item.append(render_field(field, item,
+                                                  class_renderers))
                 grid_items.append(grid_item)
             data_dict['items'] = grid_items
 
             #pagination handling
             pagination = Pagination(total=len(items), page=page,
-                search=False, record_name=cls.plural_name,
-                per_page=ITEMS_PER_PAGE, alignment="centered")
+                                    search=False, record_name=cls.plural_name,
+                                    per_page=ITEMS_PER_PAGE,
+                                    alignment="centered")
             data_dict['pagination'] = pagination
 
             # render the chart if it's configured
             if cls.__name__ in self.renderers and \
-                "__index_chart" in self.renderers[cls.__name__]:
+                    "__index_chart" in self.renderers[cls.__name__]:
                 chart = self.renderers[cls.__name__]["__index_chart"]()
                 data_dict["index_chart"] = chart.render(items)
 
@@ -230,9 +235,9 @@ class Site(object):
                 if item[0] in self.renderers else []
 
             params = {getattr(cls, "pk_field"): pk_}
-            item = cls.get(**params)
+            item = cls.one(**params)
             if item is None:
-                data_dict['message'] = "The item with id <strong>%s</strong> does not exist for class %s"  % (pk_, name)
+                data_dict['message'] = "The item with id <strong>%s</strong> does not exist for class %s" % (pk_, name)
                 return render_template("404.html", **data_dict), 404
 
             # rendering the fields for the class.
@@ -241,7 +246,7 @@ class Site(object):
                 attrs.append(render_field(field, item, class_renderers))
             for bw_rel in item.backwards_relations:
                 attrs.append(render_field(bw_rel, item, class_renderers,
-                                            True))
+                                          True))
 
             data_dict['item'] = item
             data_dict['pk'] = pk_
